TEMPLATES = {
    "rdm-record-metadata": "templates/rdm_record_metadata.py.jinja2",
    "rdm-record": "templates/rdm_record.py.jinja2",
    "rdm-draft-record": "templates/rdm_draft_record.py.jinja2",
    "rdm-record-search-options": "templates/rdm_record_search_options.py.jinja2",
    "rdm-ext": "templates/rdm_ext.py.jinja2",
    "rdm-ext-draft": "templates/rdm_ext_draft.py.jinja2",
}
